跳到正文
Hacker News· nikolay·· 31 分钟前AI 评分36

Python 3.15 惰性导入实测:CLI 启动快 4 倍,但并非处处有效

Adopting Python 3.15's lazy imports: a 4× faster CLI, and where they didn't help

AI 导读

团队将后台迁移到 Python 3.15.2,用 PEP 810 显式惰性导入后 CLI 的 --help 从 2230 ms 降至 474 ms,TUI 从 3615 ms 降至 209 ms,MCP server 导入从 5667 ms 降至 1682 ms。

来源:Hacker News · namegarage.com